// ignore_for_file: must_be_immutable

library input_drop;

import 'package:flutter/material.dart';

class InputDropDown extends StatefulWidget {
  String label;
  String emptyMessage;
  List list;
  double dropsize;
  String strigFilter;
  bool centerItems;
  late Function onChanged;
  late Function onFieldSubmitted;

  TextEditingController fieldController;
  InputDropDown({
    required this.label,
    required this.emptyMessage,
    required this.list,
    required this.strigFilter,
    required this.centerItems,
    required this.dropsize,
    required this.fieldController,
    onChanged,
    onFieldSubmitted,
  });

  @override
  State<InputDropDown> createState() => _InputDropDownState();
}

class _InputDropDownState extends State<InputDropDown> {
  bool emptyList = false;
  bool createButton = false;
  bool showList = false;
  late Map list;
  @override
  void initState() {
    super.initState();
    setState(() {
      list = Map.from(widget.list.asMap());
    });
  }

  @override
  Widget build(BuildContext context) {
    return Stack(
      children: [
        Padding(
          padding: const EdgeInsets.only(top: 10),
          child: AnimatedOpacity(
            duration: const Duration(seconds: 1),
            curve: Curves.fastOutSlowIn,
            opacity: showList == false ? 0 : 1,
            child: AnimatedContainer(
              duration: const Duration(seconds: 1),
              curve: Curves.fastOutSlowIn,
              height: showList == false ? 0 : widget.dropsize,
              width: double.maxFinite,
              decoration: BoxDecoration(
                boxShadow: [
                  BoxShadow(
                    color: Theme.of(context).brightness == Brightness.light
                        ? Colors.grey.withOpacity(0.2)
                        : Colors.black.withOpacity(0.2),
                    spreadRadius: 5,
                    blurRadius: 7,
                    offset: const Offset(0, 3), // changes position of shadow
                  ),
                ],
                color: Theme.of(context).brightness == Brightness.light
                    ? Colors.white
                    : Colors.grey[800],
                borderRadius: BorderRadius.circular(25),
              ),
              child: Padding(
                padding: const EdgeInsets.only(top: 60),
                child: SingleChildScrollView(
                  child: ListView.builder(
                    primary: false,
                    shrinkWrap: true,
                    physics: const NeverScrollableScrollPhysics(),
                    itemCount: widget.list.isEmpty ? 1 : list.length,
                    itemBuilder: (BuildContext context, int index) {
                      if (widget.list.isEmpty) {
                        return Padding(
                          padding:
                              const EdgeInsets.symmetric(vertical: 10, horizontal: 10),
                          child: Row(
                            mainAxisAlignment: MainAxisAlignment.center,
                            children: [Text(widget.emptyMessage)],
                          ),
                        );
                      } else {
                        return Padding(
                          padding: const EdgeInsets.symmetric(
                            horizontal: 10,
                          ),
                          child: Column(
                            children: [
                              MaterialButton(
                                onPressed: () {
                                  setState(() {
                                    showList = false;
                                    widget.fieldController.text =
                                        list[index][widget.strigFilter];
                                  });
                                },
                                child: Row(
                                  mainAxisAlignment: widget.centerItems == true
                                      ? MainAxisAlignment.center
                                      : MainAxisAlignment.start,
                                  children: [
                                    Flexible(
                                      child: Text(
                                        list[index][widget.strigFilter],
                                        style: TextStyle(
                                          color: Theme.of(context).brightness ==
                                                  Brightness.light
                                              ? Colors.grey[700]
                                              : Colors.white,
                                        ),
                                      ),
                                    ),
                                  ],
                                ),
                              ),
                              const Divider(),
                            ],
                          ),
                        );
                      }
                    },
                  ),
                ),
              ),
            ),
          ),
        ),
        Container(
          width: double.maxFinite,
          decoration: BoxDecoration(
            boxShadow: [
              BoxShadow(
                color: Theme.of(context).brightness == Brightness.light
                    ? Colors.grey.withOpacity(0.2)
                    : Colors.black.withOpacity(0.2),
                spreadRadius: 5,
                blurRadius: 7,
                offset: const Offset(0, 3), // changes position of shadow
              ),
            ],
            color: Theme.of(context).brightness == Brightness.light
                ? Colors.white
                : Colors.grey[800],
            borderRadius: BorderRadius.circular(50),
          ),
          child: TextFormField(
            autofocus: false,
            controller: widget.fieldController,
            onChanged: (text) async {},
            onFieldSubmitted: (value) {},
            onTap: () {
              setState(() {
                showList = true;
              });
            },
            decoration: InputDecoration(
              border: InputBorder.none,
              hintText: widget.label,
              prefixIcon: Icon(
                Icons.search,
                color: Theme.of(context).brightness == Brightness.light
                    ? Colors.black.withOpacity(0.5)
                    : Colors.white,
              ),
              prefixIconConstraints: const BoxConstraints(
                maxHeight: 35,
                minHeight: 35,
                maxWidth: 50,
                minWidth: 50,
              ),
              suffixIcon: InkWell(
                onTap: () {
                  setState(() {
                    widget.fieldController.clear();
                    showList = false;
                  });
                },
                child: Icon(
                  Icons.clear,
                  color: Theme.of(context).brightness == Brightness.light
                      ? Colors.black.withOpacity(0.5)
                      : Colors.white,
                ),
              ),
              suffixIconConstraints: const BoxConstraints(
                maxHeight: 35,
                minHeight: 35,
                maxWidth: 50,
                minWidth: 50,
              ),
            ),
          ),
        ),
      ],
    );
  }
}
